[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]

[minion-cvs] it"s possible that "persistant" is a technical python t...



Update of /home/minion/cvsroot/src/minion/lib/mixminion
In directory moria:/home/arma/work/minion/cvs/src/minion/lib/mixminion

Modified Files:
	Filestore.py 
Log Message:
it's possible that 'persistant' is a technical python term, but i hope not.


Index: Filestore.py
===================================================================
RCS file: /home/minion/cvsroot/src/minion/lib/mixminion/Filestore.py,v
retrieving revision 1.25
retrieving revision 1.26
diff -u -d -r1.25 -r1.26
--- Filestore.py	4 Jun 2005 13:46:01 -0000	1.25
+++ Filestore.py	4 Nov 2005 02:07:16 -0000	1.26
@@ -55,7 +55,7 @@
        mixin classes below.
 
        Abstractly, a BaseStore is a consistent collection of 'things'
-       with (optional) persistant metadata.  The 'things' support
+       with (optional) persistent metadata.  The 'things' support
        insert, move, and delete operations.  The metadata supports
        modification.
 
@@ -616,7 +616,7 @@
 
 
 class DBBase:
     """A DBBase is a persistant store that maps keys to values, using
        a Python anydbm object.
 
        It differs from the standard python 'shelve' module:
@@ -874,7 +874,7 @@
         return 1
 
 class WritethroughDict:
     """A persistant mapping from string to pickleable object.  The entire
        mapping is cached in memory, but all modifications are written through
        to disk immediately.
     """
@@ -616,7 +616,7 @@
 
 class DBBase:
-    """A DBBase is a persistant store that maps keys to values, using
+    """A DBBase is a persistent store that maps keys to values, using
        a Python anydbm object.
 
@@ -874,7 +874,7 @@
 
 class WritethroughDict:
-    """A persistant mapping from string to pickleable object.  The entire
+    """A persistent mapping from string to pickleable object.  The entire
        mapping is cached in memory, but all modifications are written through
        to disk immediately.